
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/


#include "peptidextp.h"
#include <QStringList>

PeptideXtp::PeptideXtp(const QString & pepstr):pappso::Peptide(pepstr)
{

}

PeptideXtp::PeptideXtp(const PeptideXtp& other):pappso::Peptide(other)
{

}

PeptideXtp::~PeptideXtp()
{

}

const QString PeptideXtp::getModifString() const {
    QStringList modif_list;
    unsigned int i=1;
    for (const pappso::Aa & amino_acid:_aa_vec) {
        std::list<pappso::AaModificationP> aa_modif_list = amino_acid.getModificationList();
        QStringList aamodif;
        for (auto && aa_modif : aa_modif_list) {
            if (!aa_modif->isInternal()) {
                aamodif << QString::number(aa_modif->getMass(), 'f', 2);
            }
        }
        QString mod_str(aamodif.join("|"));
        if (!mod_str.isEmpty()) {
            modif_list << QString("%1%2:%3").arg(i).arg(amino_acid.getLetter()).arg(mod_str);
        }
        i++;
    }
    //return QString ("%1 %2").arg(modif_list.join(" ")).arg(this->toAbsoluteString());
    return modif_list.join(" ");
}

PeptideXtpSp PeptideXtp::makePeptideXtpSp() const {
    return std::make_shared<PeptideXtp>(*this);
}


pappso::mz PeptideXtp::getGroupingMass() const {
    return getNativePeptideP()->getMass();
}

const pappso::Peptide * PeptideXtp::getNativePeptideP() const {
    if (_sp_native_peptide.get() == nullptr) {
        return this;
    }
    return _sp_native_peptide.get();
}

bool PeptideXtp::replaceModification(pappso::AaModificationP oldmod, pappso::AaModificationP newmod) {
    
    pappso::Peptide::replaceAaModification(oldmod, newmod);
    if (_sp_native_peptide.get() != nullptr) {
        //_sp_native_peptide.get()->replaceAaModification(oldmod, newmod);
    }
    
}
